===============
template_to_pdf
===============

|CI Build Status|

----

Olist custom pre-commit plugins


Usage
~~~~~

TBD

Development
~~~~~~~~~~~

TBD


Release
~~~~~~~

Check if ``CHANGES.rst`` contains the correct version number (follow semver_).
Create the proper tags with::

    make release


.. _semver: https://semver.org/
.. |CI Build Status| image:: https://circleci.com/gh/olist/template_to_pdf.svg?style=svg
